@@ -1,13 +1,17 @@
-﻿define(['paperdialoghelper', 'paper-checkbox', 'paper-dialog', 'paper-input', 'paper-item-body', 'paper-icon-item', 'paper-textarea', 'paper-fab'], function (paperDialogHelper) {
+﻿define(['dialogHelper', 'jQuery', 'paper-checkbox', 'paper-input', 'paper-item-body', 'paper-icon-item', 'paper-textarea', 'paper-fab'], function (dialogHelper, $) {
 
     var currentContext;
     var metadataEditorInfo;
     var currentItem;
 
+    function isDialog() {
+        return currentContext.classList.contains('dialog');
+    }
+
     function closeDialog(isSubmitted) {
 
-        if (currentContext.tagName == 'PAPER-DIALOG') {
-            paperDialogHelper.close(currentContext);
+        if (isDialog()) {
+            dialogHelper.close(currentContext);
         }
     }
 
@@ -15,7 +19,9 @@
 
         function afterContentTypeUpdated() {
 
-            Dashboard.alert(Globalize.translate('MessageItemSaved'));
+            require(['toast'], function (toast) {
+                toast(Globalize.translate('MessageItemSaved'));
+            });
 
             Dashboard.hideLoadingMsg();
             closeDialog(true);
@@ -342,6 +348,12 @@
 
         var items = [];
 
+        items.push({
+            name: Globalize.translate('ButtonEditImages'),
+            id: 'images',
+            ironIcon: 'photo'
+        });
+
         items.push({
             name: Globalize.translate('ButtonIdentify'),
             id: 'identify',
@@ -369,6 +381,9 @@
                         case 'refresh':
                             showRefreshMenu(context, button);
                             break;
+                        case 'images':
+                            LibraryBrowser.editImages(currentItem.Id);
+                            break;
                         default:
                             break;
                     }
@@ -403,6 +418,18 @@
         Events.off(ApiClient, "websocketmessage", onWebSocketMessageReceived);
     }
 
+    function onEditorClick(e) {
+        var btnRemoveFromEditorList = parentWithClass(e.target, 'btnRemoveFromEditorList');
+        if (btnRemoveFromEditorList) {
+            removeElementFromListview(btnRemoveFromEditorList);
+        }
+
+        var btnAddTextItem = parentWithClass(e.target, 'btnAddTextItem');
+        if (btnAddTextItem) {
+            addElementToEditableListview(btnAddTextItem);
+        }
+    }
+
     function init(context) {
 
         $('.btnCancel', context).on('click', function () {
@@ -429,19 +456,8 @@
             }
         });
 
-        context.addEventListener('click', function (e) {
-
-            var btnRemoveFromEditorList = parentWithClass(e.target, 'btnRemoveFromEditorList');
-            if (btnRemoveFromEditorList) {
-                removeElementFromListview(btnRemoveFromEditorList);
-            }
-
-            var btnAddTextItem = parentWithClass(e.target, 'btnAddTextItem');
-            if (btnAddTextItem) {
-                addElementToEditableListview(btnAddTextItem);
-            }
-
-        });
+        context.removeEventListener('click', onEditorClick);
+        context.addEventListener('click', onEditorClick);
 
         $('form', context).off('submit', onSubmit).on('submit', onSubmit);
 
@@ -451,7 +467,7 @@
         });
 
         // For now this is only supported in dialog mode because we have a way of knowing when it closes
-        if (currentContext.tagName == 'PAPER-DIALOG') {
+        if (isDialog()) {
             bindItemChanged(context);
         }
     }
@@ -563,7 +579,7 @@
             html += '</div>';
         }
 
-        var elem = $('.externalIds', context).html(html).trigger('create');
+        var elem = $('.externalIds', context).html(html);
 
         $('.txtExternalId', elem).on('change', onExternalIdChange).trigger('change');
     }
@@ -1208,7 +1224,7 @@
                 xhr.onload = function (e) {
 
                     var template = this.response;
-                    var dlg = paperDialogHelper.createDialog({
+                    var dlg = dialogHelper.createDialog({
                         removeOnClose: true,
                         size: 'medium'
                     });
@@ -1225,10 +1241,10 @@
                     dlg.innerHTML = html;
                     document.body.appendChild(dlg);
 
-                    paperDialogHelper.open(dlg);
+                    dialogHelper.open(dlg);
 
-                    dlg.addEventListener('iron-overlay-closed', function () {
-                        bindItemChanged(context);
+                    dlg.addEventListener('close', function () {
+                        unbindItemChanged(dlg);
                         resolve();
                     });
 
