@@ -14,6 +14,7 @@
 
                 page.querySelector('.txtDevicePath').value = info.Url || '';
                 page.querySelector('.chkFavorite').checked = info.ImportFavoritesOnly;
+                page.querySelector('.chkTranscode').checked = info.AllowHWTranscoding;
                 page.querySelector('.chkEnabled').checked = info.IsEnabled;
 
             });
@@ -30,6 +31,7 @@
             Type: 'hdhomerun',
             Url: page.querySelector('.txtDevicePath').value,
             ImportFavoritesOnly: page.querySelector('.chkFavorite').checked,
+            AllowHWTranscoding: page.querySelector('.chkTranscode').checked,
             IsEnabled: page.querySelector('.chkEnabled').checked,
             DataVersion: 1
         };
