@@ -1,10 +1,12 @@
-﻿(function () {
+﻿define(['jQuery'], function ($) {
 
     function changeCollectionType(page, virtualFolder) {
 
-        Dashboard.alert({
-            message: Globalize.translate('HeaderChangeFolderTypeHelp'),
-            title: Globalize.translate('HeaderChangeFolderType')
+        require(['alert'], function (alert) {
+            alert({
+                title: Globalize.translate('HeaderChangeFolderType'),
+                text: Globalize.translate('HeaderChangeFolderTypeHelp')
+            });
         });
     }
 
@@ -53,17 +55,16 @@
             msg += virtualFolder.Locations.join("<br/>");
         }
 
-        Dashboard.confirm(msg, Globalize.translate('HeaderRemoveMediaFolder'), function (confirmResult) {
+        require(['confirm'], function (confirm) {
 
-            if (confirmResult) {
+            confirm(msg, Globalize.translate('HeaderRemoveMediaFolder')).then(function () {
 
                 var refreshAfterChange = shouldRefreshLibraryAfterChanges(page);
 
                 ApiClient.removeVirtualFolder(virtualFolder.Name, refreshAfterChange).then(function () {
                     reloadLibrary(page);
                 });
-            }
-
+            });
         });
     }
 
@@ -102,6 +103,12 @@
             ironIcon: 'videocam'
         });
 
+        menuItems.push({
+            name: Globalize.translate('ButtonEditImages'),
+            id: 'editimages',
+            ironIcon: 'photo'
+        });
+
         menuItems.push({
             name: Globalize.translate('ButtonManageFolders'),
             id: 'edit',
@@ -135,6 +142,9 @@
                         case 'edit':
                             editVirtualFolder(page, virtualFolder);
                             break;
+                        case 'editimages':
+                            editImages(page, virtualFolder);
+                            break;
                         case 'rename':
                             renameVirtualFolder(page, virtualFolder);
                             break;
@@ -205,21 +215,26 @@
                 return;
             }
 
-            require(['components/imageeditor/imageeditor'], function (ImageEditor) {
-
-                ImageEditor.show(virtualFolder.ItemId, {
-                    theme: 'a'
-                }).then(function (hasChanged) {
-                    if (hasChanged) {
-                        reloadLibrary(page);
-                    }
-                });
-            });
+            editVirtualFolder(page, virtualFolder);
         });
 
         Dashboard.hideLoadingMsg();
     }
 
+    function editImages(page, virtualFolder) {
+
+        require(['components/imageeditor/imageeditor'], function (ImageEditor) {
+
+            ImageEditor.show(virtualFolder.ItemId, {
+                theme: 'a'
+            }).then(function (hasChanged) {
+                if (hasChanged) {
+                    reloadLibrary(page);
+                }
+            });
+        });
+    }
+
     function getCollectionTypeOptions() {
 
         return [
@@ -418,6 +433,42 @@
         });
     });
 
+    window.WizardLibraryPage = {
+
+        next: function () {
+
+            Dashboard.showLoadingMsg();
+
+            var apiClient = ApiClient;
+
+            apiClient.ajax({
+                type: "POST",
+                url: apiClient.getUrl('System/Configuration/MetadataPlugins/Autoset')
+
+            }).then(function () {
+
+                Dashboard.hideLoadingMsg();
+                Dashboard.navigate('wizardsettings.html');
+            });
+        }
+    };
+
+    function getTabs() {
+        return [
+        {
+            href: 'library.html',
+            name: Globalize.translate('TabFolders')
+        },
+         {
+             href: 'librarypathmapping.html',
+             name: Globalize.translate('TabPathSubstitution')
+         },
+         {
+             href: 'librarysettings.html',
+             name: Globalize.translate('TabAdvanced')
+         }];
+    }
+
     pageClassOn('pageshow', "mediaLibraryPage", function () {
 
         var page = this;
@@ -425,32 +476,9 @@
 
     });
 
-})();
-
-var WizardLibraryPage = {
-
-    next: function () {
-
-        Dashboard.showLoadingMsg();
-
-        var apiClient = ApiClient;
-
-        apiClient.ajax({
-            type: "POST",
-            url: apiClient.getUrl('System/Configuration/MetadataPlugins/Autoset')
-
-        }).then(function () {
-
-            Dashboard.hideLoadingMsg();
-            Dashboard.navigate('wizardsettings.html');
-        });
-    }
-};
-
-(function ($, document, window) {
-
     pageIdOn('pageshow', "mediaLibraryPage", function () {
 
+        LibraryMenu.setTabs('librarysetup', 0, getTabs);
         var page = this;
 
         // on here
@@ -473,4 +501,4 @@ var WizardLibraryPage = {
 
     });
 
-})(jQuery, document, window);
\ No newline at end of file
+});
\ No newline at end of file
