@@ -1,4 +1,4 @@
-﻿(function ($, document, window) {
+﻿define(['jQuery'], function ($) {
 
     var metadataKey = "xbmcmetadata";
 
@@ -41,12 +41,29 @@
         return false;
     }
 
+    function getTabs() {
+        return [
+        {
+            href: 'metadata.html',
+            name: Globalize.translate('TabSettings')
+        },
+         {
+             href: 'metadataimages.html',
+             name: Globalize.translate('TabServices')
+         },
+         {
+             href: 'metadatanfo.html',
+             name: Globalize.translate('TabNfoSettings')
+         }];
+    }
+
     $(document).on('pageinit', "#metadataNfoPage", function () {
 
         $('.metadataNfoForm').off('submit', onSubmit).on('submit', onSubmit);
 
     }).on('pageshow', "#metadataNfoPage", function () {
 
+        LibraryMenu.setTabs('metadata', 2, getTabs);
         Dashboard.showLoadingMsg();
 
         var page = this;
@@ -60,4 +77,4 @@
         });
     });
 
-})(jQuery, document, window);
+});
