@@ -123,6 +123,18 @@
         });
     }
 
+    function getTabs() {
+        return [
+        {
+            href: 'dashboardhosting.html',
+            name: Globalize.translate('TabHosting')
+        },
+         {
+             href: 'serversecurity.html',
+             name: Globalize.translate('TabSecurity')
+         }];
+    }
+
     pageIdOn('pageinit', "serverSecurityPage", function () {
 
         var page = this;
@@ -136,6 +148,7 @@
     });
     pageIdOn('pagebeforeshow', "serverSecurityPage", function () {
 
+        LibraryMenu.setTabs('adminadvanced', 1, getTabs);
         var page = this;
 
         loadData(page);
